import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.Frame;
import java.awt.GridLayout;
import java.awt.Toolkit;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;

import javax.swing.BorderFactory;
import javax.swing.ImageIcon;
import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JMenu;
import javax.swing.JMenuBar;
import javax.swing.JMenuItem;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JSplitPane;
import javax.swing.JTabbedPane;
import javax.swing.JTable;
import javax.swing.JTextArea;
import javax.swing.JTextField;
import javax.swing.JToolBar;
import javax.swing.JTree;
import javax.swing.tree.DefaultMutableTreeNode;

import org.gui.JCascadedPane;
import org.gui.JPanelGroup;


/*
 * This is a sample program created
 * using JCascadedPane library. It must
 * be compiled and executed in jdk1.4.x
 * versions. To run it in jdk1.2 or higher
 * simply remove or comment out the method setExpandedState()
 * used in the program below.
 */

public class JPanelGroupTest extends JFrame
{
	JPanelGroupTest()
	{
		Dimension screenSize = Toolkit.getDefaultToolkit().getScreenSize();
		
		//creating menu bar
		createMenuBar();
		//creating toolbar
		createToolBar();	

		//creating JPanelGroup object to hold cascaded panes
		JPanelGroup panelGroup = new JPanelGroup();
		
		//creating a few cascaded panes holding a child component
		JCascadedPane expandablePanel1 = new JCascadedPane("Panel 1", createPanel1());
		expandablePanel1.setToolTipText("Click here to open");
		JCascadedPane expandablePanel2 = new JCascadedPane("Panel 2", createPanel2());
		expandablePanel2.setToolTipText("Click here to open");
		JCascadedPane expandablePanel3 = new JCascadedPane("Panel 3", createPanel3());
		expandablePanel3.setToolTipText("Click here to open");
				
		/*
		 * adding JCascadedPane to panel group. It is recommended
		 * to use addPanel() method to do this job. With this we
		 * have finished creating our cascaded panes in less than
		 * 10 lines of code.
		 */
		 
		panelGroup.addPanel(expandablePanel1);
		panelGroup.addPanel(expandablePanel2);
		panelGroup.addPanel(expandablePanel3);
		
		/*
		 * Adding a new split pane
		 */		

		JSplitPane horizontalSplitPane = new JSplitPane(JSplitPane.HORIZONTAL_SPLIT, new JScrollPane(new JTextArea()), panelGroup);
		horizontalSplitPane.setOneTouchExpandable(true);
		horizontalSplitPane.setDividerSize(10);
		horizontalSplitPane.setDividerLocation(screenSize.width - screenSize.width/4);

		/* 
		 * creating a new JPanelGroup to hold other set
		 * of JCascadedPane.
		 */

		JPanelGroup panelGroup1 = new JPanelGroup();
		JCascadedPane expandablePanel4 = new JCascadedPane("Panel 1", createPanel2());
		expandablePanel4.setToolTipText("Click here to open");
		panelGroup1.addPanel(expandablePanel4);


		/*
		 * Adding previous horizontalSplitPane and above JPanelGroup
		 * in a new Split Pane.
		 */
		 
		JSplitPane verticalSplitPane = new JSplitPane(JSplitPane.VERTICAL_SPLIT, horizontalSplitPane, panelGroup1);
		verticalSplitPane.setOneTouchExpandable(true);
		verticalSplitPane.setDividerSize(10);
		verticalSplitPane.setDividerLocation(screenSize.height - screenSize.height/2);		

		getContentPane().add(verticalSplitPane);
		setSize(screenSize.width, screenSize.height);
		setTitle("JCascadedPane Demo");
		setVisible(true);
		
		/*
		 * Comment out this method to run your program in
		 * JDK 1.2 or higher
		 */
		 
		setExtendedState(Frame.MAXIMIZED_BOTH);
		
		addWindowListener(new WindowAdapter()
		{
			public void windowClosing(WindowEvent e)
			{
				System.exit(0);
			}
		});
	}

	/*
	 * create a ToolBar.
	 */
	private void createToolBar()
	{
		JToolBar toolBar = new JToolBar();
		toolBar.add(new JButton(new ImageIcon("./images/new16.gif")));
		toolBar.add(new JButton(new ImageIcon("./images/open16.gif")));
		toolBar.add(new JButton(new ImageIcon("./images/save16.gif")));
		toolBar.addSeparator();
		toolBar.add(new JButton(new ImageIcon("./images/cut16.gif")));
		toolBar.add(new JButton(new ImageIcon("./images/copy16.gif")));		
		toolBar.add(new JButton(new ImageIcon("./images/paste16.gif")));		
		this.getContentPane().add(toolBar, BorderLayout.NORTH);
	}


	/*
	 * create a MenuBar.
	 */
	
	private void createMenuBar()
	{
		JMenuBar menuBar = new JMenuBar();
		JMenu file = new JMenu("File");
		JMenu edit = new JMenu("Edit");
		JMenu help = new JMenu("Help");
		JMenuItem newFile = new JMenuItem("New ...");
		JMenuItem openFile = new JMenuItem("Open ...");
		JMenuItem saveFile = new JMenuItem("Save ...");		
		JMenuItem saveasFile = new JMenuItem("Save As ...");				
		JMenuItem pageFile = new JMenuItem("Page Setup ...");
		JMenuItem previewFile = new JMenuItem("Print Preview...");		
		JMenuItem printFile = new JMenuItem("Print ...");
		JMenuItem cut = new JMenuItem("Cut");
		JMenuItem copy = new JMenuItem("Copy");		
		JMenuItem paste = new JMenuItem("Paste");		
		JMenuItem select = new JMenuItem("Select All");
		JMenuItem find = new JMenuItem("Find And Replace ...");		
		JMenuItem welcome = new JMenuItem("Welcome ...");		
		JMenuItem contents = new JMenuItem("Help Contents");		
		JMenuItem about = new JMenuItem("About JCascadedPanel Demo");
		JMenuItem exit = new JMenuItem("Exit");		

		file.add(newFile);
		file.add(openFile);
		file.addSeparator();
		file.add(saveFile);
		file.add(saveasFile);		
		file.addSeparator();
		file.add(pageFile);		
		file.add(previewFile);
		file.add(printFile);
		file.addSeparator();				
		file.add(exit);

		edit.add(cut);
		edit.add(copy);
		edit.add(paste);		
		edit.addSeparator();
		edit.add(select);
		edit.addSeparator();
		edit.add(find);		
		
		help.add(welcome);
		help.add(contents);
		help.addSeparator();
		help.add(about);

		menuBar.add(file);
		menuBar.add(edit);
		menuBar.add(help);
						
		this.setJMenuBar(menuBar);
	}

	/* 
	 * create a JPanel holding 30 buttons
	 */
	 
	public JPanel createPanel1()
	{
		JPanel panel1 = new JPanel();
		panel1.setLayout(new GridLayout(30,1));
		
		for(int i =0; i<30; i++)
		{
			panel1.add(new JButton("Button "+(i+1)));
		}	
		panel1.setBorder(BorderFactory.createEmptyBorder(10,10,10,10));
		JPanel panel2 = new JPanel();
		panel2.setLayout(new BorderLayout());
		panel2.add(new JScrollPane(panel1));
		return panel2;
	}

	/*
	 * create a JTabbedPane holding a JTree under one
	 * Tab and JTable in other
	 */

	public JTabbedPane createPanel2()
	{
		JTabbedPane tabbedPane = new JTabbedPane();
		JPanel panel1 = new JPanel();
		panel1.setLayout(new BorderLayout(5,5));
		DefaultMutableTreeNode top = new DefaultMutableTreeNode("Options");
		DefaultMutableTreeNode a = new DefaultMutableTreeNode("A");
		DefaultMutableTreeNode a1 = new DefaultMutableTreeNode("A1");
		DefaultMutableTreeNode a2 = new DefaultMutableTreeNode("A2");
		a.add(a1);
		a.add(a2);
		
		DefaultMutableTreeNode b = new DefaultMutableTreeNode("B");
		DefaultMutableTreeNode b1 = new DefaultMutableTreeNode("B1");
		DefaultMutableTreeNode b2 = new DefaultMutableTreeNode("B2");		
		DefaultMutableTreeNode b3 = new DefaultMutableTreeNode("B3");				
		b.add(b1);
		b.add(b2);
		b.add(b3);	
		
		DefaultMutableTreeNode c = new DefaultMutableTreeNode("C");
		DefaultMutableTreeNode c1 = new DefaultMutableTreeNode("C1");
		DefaultMutableTreeNode c2 = new DefaultMutableTreeNode("C2");		
		DefaultMutableTreeNode c3 = new DefaultMutableTreeNode("C3");				
		c.add(c1);
		c.add(c2);
		c.add(c3);	

		top.add(a);	
		top.add(b);		
		top.add(c);		
		
		JTree jtree = new JTree(top);
		
		panel1.add(new JLabel("Example using JTree"), BorderLayout.NORTH);
		panel1.add(new JScrollPane(jtree), BorderLayout.CENTER);
		
		panel1.setBorder(BorderFactory.createEmptyBorder(10,10,10,10));
		tabbedPane.addTab("Tab 1", panel1);

		JPanel panel2 = new JPanel();
		panel2.setLayout(new BorderLayout(5,5));

		final String[] columnHeads = {"Name","Phone", "Fax"};
		
		final Object[][] data = {
			{"John", "4231", "8622"},
			{"Raju", "4232", "8655"},
			{"Bob", "6654", "5543"},
			{"Mark", "1235", "7655"},
			{"Matt", "3321", "8761"},
			{"Steve", "1332", "7790"},
			{"Henry", "6745", "3457"},
		};
		
		JTable table = new JTable(data, columnHeads);
		panel2.add(new JLabel("Example using JTable :"), BorderLayout.NORTH);
		panel2.add(new JScrollPane(table), BorderLayout.CENTER);
		panel2.setBorder(BorderFactory.createEmptyBorder(10,10,10,10));

		tabbedPane.addTab("Tab 2", panel2);

		return tabbedPane;
	}

	/*
	 * create a JPanel Object holding several
	 * components.
	 */

	public JPanel createPanel3()
	{

		JPanel panel1 = new JPanel();
		panel1.setLayout(new GridLayout(3,2));
		panel1.add(new JLabel("E-Mail"));
		panel1.add(new JTextField());
		panel1.add(new JLabel("Password"));
		panel1.add(new JTextField());
		panel1.add(new JButton("Submit"));
		panel1.add(new JButton("Cancel"));
		panel1.setBorder(BorderFactory.createTitledBorder("Login to Web Server"));

		JPanel panel2 = new JPanel();
		panel2.setLayout(new GridLayout(1,1));
		panel2.add(new JScrollPane(new JTextArea("Help goes here ...")));
		panel2.setBorder(BorderFactory.createTitledBorder("Help"));

		JPanel panel3 = new JPanel();
		panel3.setLayout(new BorderLayout());
		panel3.add(panel1, BorderLayout.NORTH);
		panel3.add(panel2, BorderLayout.CENTER);
		panel3.setBorder(BorderFactory.createEmptyBorder(5,5,20,5));
		return panel3;
	}
	
	public static void main(String args[]) throws Exception
	{
		JPanelGroupTest panelGroupTest = new JPanelGroupTest();
	}
}
